import { Component } from '@angular/core';
import { AlertController } from '@ionic/angular';
import * as Parse from 'parse';

@Component({
  selector: 'app-page-info',
  templateUrl: './page-info.component.html',
  styleUrls: ['./page-info.component.scss']
})
export class PageInfoComponent {
  userData = {
    name: '',
    age: null,
    gender: ''
  };

  constructor(private alertController: AlertController) {
    (Parse as any).serverURL = 'https://web2023.fmode.cn/parse';
    Parse.initialize('dev');

    const currentUser = Parse.User.current();
    if (currentUser) {
      this.userData.name = currentUser.get('name') || '';
      this.userData.age = currentUser.get('age') || null;
      this.userData.gender = currentUser.get('gender') || '';
    }
  }

  async saveInfo() {
    const { name, age, gender } = this.userData;

    try {
      const currentUser = Parse.User.current();
      if (currentUser) {
        currentUser.set('name', name);
        currentUser.set('age', age);
        currentUser.set('gender', gender);

        await currentUser.save();

        const alert = await this.alertController.create({
          header: '保存成功',
          message: '个人信息已保存。',
          buttons: ['确定']
        });

        await alert.present();
      } else {
        throw new Error('用户未登录');
      }
    } catch (error: any) {
      const alert = await this.alertController.create({
        header: '保存失败',
        message: error.message,
        buttons: ['确定']
      });

      await alert.present();
    }
  }
  }
